@@ -1,9 +1,14 @@
 #!/usr/bin/env python
 
-import typing
+import sys
+
+if sys.version_info >= (3, 8):
+    from typing import TypedDict
+else:
+    from typing_extensions import TypedDict
 
 
-class ConfigEvent(typing.TypedDict):
+class ConfigEvent(TypedDict):
     """
     MQEvent https://docs.aws.amazon.com/lambda/latest/dg/services-config.html
 
